@@ -22,9 +22,9 @@ from ask_sdk_model.directive import Directive
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.intent import Intent
+    from ask_sdk_model.intent import Intent as Intent_fd0ef0fe
 
 
 class DelegateDirective(Directive):
@@ -46,7 +46,7 @@ class DelegateDirective(Directive):
     supports_multiple_types = False
 
     def __init__(self, updated_intent=None):
-        # type: (Optional[Intent]) -> None
+        # type: (Optional[Intent_fd0ef0fe]) -> None
         """
 
         :param updated_intent: 
